Credits
-------

`metabolinks` core team @FCUL:

- António Ferreira [(@aeferreira)](https://github.com/aeferreira)
  - Main project designer
  - MS Data representation
  - peak list alignment
- Francisco Traquete [(@Francisco-T)](https://github.com/Francisco-T)
  - preprocessing
  - data analysis methods

Past `metabolinks` contributors:

- Beatriz Lima [(@beatriz-lima)](https://github.com/beatriz-lima)
  - Chemont integration code
- Gil Pires [(@gilpires97)](https://github.com/gilpires97)


For a full list of contributors you can mine the commit history:

https://github.com/aeferreira/metabolinks/commits/develop
